@@ -11,7 +11,7 @@ commandline with a @ prefix (e.g. @foo.conf).
 
 at least path and repo need to be specified."""
 
-__version_info__ = ('1', '1')
+__version_info__ = ('1', '2')
 __version__ = '.'.join(__version_info__)
 __author__ = 'Antoine Beaupré'
 __email__ = 'anarcat@debian.org'
@@ -95,6 +95,9 @@ class ArgumentConfigParser(argparse.ArgumentParser):
                            help="""a SSH address to save the backup remotely
                            (example: bup@example.com:repos/repo.bup)""")
         group.add_argument('-x', '--exclude', action='append',
+                           help="""exclude regex pattern,
+                                   will be passed as --exclude to bup""")
+        group.add_argument('--exclude-rx', action='append',
                            help="""exclude regex pattern,
                                    will be passed as --exclude-rx to bup""")
         group = self.add_argument_group('Extra jobs',
@@ -757,7 +760,7 @@ class GlobalLogger(Singleton):
             # setup python logging facilities
             if args.syslog:
                 sl = logging.handlers.SysLogHandler(address='/dev/log')
-                sl.setFormatter(logging.Formatter('%(filename)s[%(process)d]: %(message)s'))
+                sl.setFormatter(logging.Formatter('bup-cron[%(process)d]: %(message)s'))
                 # convert syslog argument to a numeric value
                 loglevel = getattr(logging, args.syslog.upper(), None)
                 if not isinstance(loglevel, int):
@@ -933,6 +936,24 @@ Remote versions
 ''' % (self.remote_bup, self.remote_git, self.remote_python)
         return str
 
+    def oneline(self):
+        size_diff = self.sizes[-1] - self.sizes[-2]
+        str = 'repository size (before/after/diff): %s/%s/%s (%s/%s/%s), version (bup/git/python): %s/%s/%s' \
+              % (
+                  self.format_bytes(self.sizes[-2]),
+                  self.format_bytes(self.sizes[-1]),
+                  self.format_bytes(size_diff),
+                  self.sizes[-2],
+                  self.sizes[-1],
+                  size_diff,
+                  self.local_bup,
+                  self.local_git,
+                  self.local_python)
+        if self.remote:
+            str += ', remote versions (bup/git/python): %s/%s/%s' \
+                   % (self.remote_bup, self.remote_git, self.remote_python)
+        return str
+
     def save(self):
         self.disk_usage()
         # We must use a temporary file otherwise the EOL are not written
@@ -947,8 +968,11 @@ Remote versions
                                                                      self.branch)]
         logging.debug('calling command `%s`' % cmd)
         process = subprocess.Popen(cmd, stdin=subprocess.PIPE,
-                                   stdout=subprocess.PIPE)
+                                   stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE)
         (out, err) = process.communicate(str(self))
+        logging.debug('output: `%s %s` (%d)' % (out, err, process.returncode))
+        return process.returncode == 0
 
 
 def process(args):
@@ -969,7 +993,7 @@ def process(args):
             # able to index multiple paths
             #
             # unfortunately, `bup index -x / /var` skips /var...
-            if not Bup.index(snapshot.path, args.exclude, None, True):
+            if not Bup.index(snapshot.path, args.exclude, args.exclude_rx, True):
                 logging.error('skipping save because index failed!')
                 success = False
                 continue
@@ -983,6 +1007,7 @@ def process(args):
                 args.stats.branch = branch
                 if not args.stats.save():
                     logging.warn('cannot save stats note')
+                logging.info(args.stats.oneline())
 
             if args.check and not Bup.fsck(args.remote,
                                            repair=args.repair):
